@@ -24,8 +24,10 @@ class DescribeHSMBySubnetIdRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param SubnetId: Subnet标识符
+        :type SubnetId: str
         """
-        :param SubnetId: Subnet标识符\n        :type SubnetId: str\n        """
         self.SubnetId = None
 
 
@@ -46,8 +48,14 @@ class DescribeHSMBySubnetIdResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCount: HSM数量
+        :type TotalCount: int
+        :param SubnetId: 作为查询条件的SubnetId
+        :type SubnetId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCount: HSM数量\n        :type TotalCount: int\n        :param SubnetId: 作为查询条件的SubnetId\n        :type SubnetId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.SubnetId = None
         self.RequestId = None
@@ -65,8 +73,10 @@ class DescribeHSMByVpcIdRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param VpcId: VPC标识符
+        :type VpcId: str
         """
-        :param VpcId: VPC标识符\n        :type VpcId: str\n        """
         self.VpcId = None
 
 
@@ -87,8 +97,14 @@ class DescribeHSMByVpcIdResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCount: HSM数量
+        :type TotalCount: int
+        :param VpcId: 作为查询条件的VpcId
+        :type VpcId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCount: HSM数量\n        :type TotalCount: int\n        :param VpcId: 作为查询条件的VpcId\n        :type VpcId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.VpcId = None
         self.RequestId = None
@@ -106,8 +122,16 @@ class DescribeSubnetRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Limit: 返回数量。Limit需要在[1, 100]之间。
+        :type Limit: int
+        :param Offset: 偏移量。偏移量最小为0。
+        :type Offset: int
+        :param VpcId: 查询指定VpcId下的子网信息。
+        :type VpcId: str
+        :param SearchWord: 查找关键字
+        :type SearchWord: str
         """
-        :param Limit: 返回数量。\n        :type Limit: int\n        :param Offset: 偏移量。\n        :type Offset: int\n        :param VpcId: 查询指定VpcId下的子网信息。\n        :type VpcId: str\n        :param SearchWord: 查找关键字\n        :type SearchWord: str\n        """
         self.Limit = None
         self.Offset = None
         self.VpcId = None
@@ -134,9 +158,15 @@ class DescribeSubnetResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCount: 返回的子网数量。
+        :type TotalCount: int
+        :param SubnetList: 返回的子网实例列表。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubnetList: list of Subnet
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCount: 返回的子网数量。\n        :type TotalCount: int\n        :param SubnetList: 返回的子网实例列表。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SubnetList: list of Subnet\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.SubnetList = None
         self.RequestId = None
@@ -158,6 +188,24 @@ class DescribeSupportedHsmRequest(AbstractModel):
 
     """
 
+    def __init__(self):
+        r"""
+        :param HsmType: Hsm类型，可选值all、virtulization、GHSM、EHSM、SHSM
+        :type HsmType: str
+        """
+        self.HsmType = None
+
+
+    def _deserialize(self, params):
+        self.HsmType = params.get("HsmType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
 
 class DescribeSupportedHsmResponse(AbstractModel):
     """DescribeSupportedHsm返回参数结构体
@@ -165,8 +213,13 @@ class DescribeSupportedHsmResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DeviceTypes: 当前地域所支持的设备列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DeviceTypes: list of DeviceInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param DeviceTypes: 当前地域所支持的设备列表\n        :type DeviceTypes: list of DeviceInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.DeviceTypes = None
         self.RequestId = None
 
@@ -187,8 +240,14 @@ class DescribeUsgRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Offset: 偏移量，当Offset和Limit均为0时将一次性返回用户所有的安全组列表。
+        :type Offset: int
+        :param Limit: 返回量，当Offset和Limit均为0时将一次性返回用户所有的安全组列表。
+        :type Limit: int
+        :param SearchWord: 搜索关键字
+        :type SearchWord: str
         """
-        :param Offset: 偏移量，当Offset和Limit均为0时将一次性返回用户所有的安全组列表。\n        :type Offset: int\n        :param Limit: 返回量，当Offset和Limit均为0时将一次性返回用户所有的安全组列表。\n        :type Limit: int\n        :param SearchWord: 搜索关键字\n        :type SearchWord: str\n        """
         self.Offset = None
         self.Limit = None
         self.SearchWord = None
@@ -213,9 +272,15 @@ class DescribeUsgResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SgList: 用户的安全组列表
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgList: list of SgUnit\n        :param TotalCount: 返回的安全组数量\n        :type TotalCount: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgList: list of SgUnit
+        :param TotalCount: 返回的安全组数量
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.SgList = None
         self.TotalCount = None
         self.RequestId = None
@@ -238,8 +303,10 @@ class DescribeUsgRuleRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param SgIds: 根据安全组Id获取安全组详情
+        :type SgIds: list of str
         """
-        :param SgIds: 根据安全组Id获取安全组详情\n        :type SgIds: list of str\n        """
         self.SgIds = None
 
 
@@ -260,10 +327,16 @@ class DescribeUsgRuleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SgRules: 安全组详情
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgRules: list of UsgRuleDetail\n        :param TotalCount: 安全组详情数量
-注意：此字段可能返回 null，表示取不到有效值。\n        :type TotalCount: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgRules: list of UsgRuleDetail
+        :param TotalCount: 安全组详情数量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.SgRules = None
         self.TotalCount = None
         self.RequestId = None
@@ -286,8 +359,14 @@ class DescribeVpcRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Offset: 返回偏移量。Offset最小为0。
+        :type Offset: int
+        :param Limit: 返回数量。Limit需要在[1, 100]之间。
+        :type Limit: int
+        :param SearchWord: 搜索关键字
+        :type SearchWord: str
         """
-        :param Offset: 返回偏移量。\n        :type Offset: int\n        :param Limit: 返回数量。\n        :type Limit: int\n        :param SearchWord: 搜索关键字\n        :type SearchWord: str\n        """
         self.Offset = None
         self.Limit = None
         self.SearchWord = None
@@ -312,9 +391,15 @@ class DescribeVpcResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCount: 可查询到的所有Vpc实例总数。
+        :type TotalCount: int
+        :param VpcList: Vpc对象列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcList: list of Vpc
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCount: 可查询到的所有Vpc实例总数。\n        :type TotalCount: int\n        :param VpcList: Vpc对象列表
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcList: list of Vpc\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.VpcList = None
         self.RequestId = None
@@ -337,8 +422,10 @@ class DescribeVsmAttributesRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param ResourceId: 资源Id
+        :type ResourceId: str
         """
-        :param ResourceId: 资源Id\n        :type ResourceId: str\n        """
         self.ResourceId = None
 
 
@@ -359,20 +446,68 @@ class DescribeVsmAttributesResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param ResourceId: 资源Id
+        :type ResourceId: str
+        :param ResourceName: 资源名称
+        :type ResourceName: str
+        :param Status: 资源状态，1表示资源为正常，2表示资源处于隔离状态
+        :type Status: int
+        :param Vip: 资源IP
+        :type Vip: str
+        :param VpcId: 资源所属Vpc
+        :type VpcId: str
+        :param SubnetId: 资源所属子网
+        :type SubnetId: str
+        :param Model: 资源所属HSM的规格
+        :type Model: str
+        :param VsmType: 资源类型，17表示EVSM，33表示GVSM，49表示SVSM
+        :type VsmType: int
+        :param RegionId: 地域Id，返回腾讯云地域代码，如广州为1，北京为8
+        :type RegionId: int
+        :param ZoneId: 区域Id，返回腾讯云每个地域的可用区代码
+        :type ZoneId: int
+        :param ExpireTime: 资源过期时间，以时间戳形式展示。
+        :type ExpireTime: int
+        :param SgList: 安全组详情信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgList: list of UsgRuleDetail
+        :param SubnetName: 子网名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubnetName: str
+        :param RegionName: 地域名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RegionName: str
+        :param ZoneName: 区域名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ZoneName: str
+        :param Expired: 实例是否已经过期
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Expired: bool
+        :param RemainSeconds: 为正数表示实例距离过期时间剩余秒数，为负数表示实例已经过期多少秒
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RemainSeconds: int
+        :param VpcName: 私有虚拟网络名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcName: str
+        :param VpcCidrBlock: VPC的IPv4 CIDR
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcCidrBlock: str
+        :param SubnetCidrBlock: 子网的CIDR
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubnetCidrBlock: str
+        :param Tags: 资源所关联的Tag
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Tags: list of Tag
+        :param RenewFlag: 资源续费标识，0表示默认状态(用户未设置，即初始状态)， 1表示自动续费，2表示明确不自动续费(用户设置)
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RenewFlag: int
+        :param Manufacturer: 厂商
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Manufacturer: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param ResourceId: 资源Id\n        :type ResourceId: str\n        :param ResourceName: 资源名称\n        :type ResourceName: str\n        :param Status: 资源状态，1表示资源为正常，2表示资源处于隔离状态\n        :type Status: int\n        :param Vip: 资源IP\n        :type Vip: str\n        :param VpcId: 资源所属Vpc\n        :type VpcId: str\n        :param SubnetId: 资源所属子网\n        :type SubnetId: str\n        :param Model: 资源所属HSM的规格\n        :type Model: str\n        :param VsmType: 资源类型，17表示EVSM，33表示GVSM，49表示SVSM\n        :type VsmType: int\n        :param RegionId: 地域Id，返回腾讯云地域代码，如广州为1，北京为8\n        :type RegionId: int\n        :param ZoneId: 区域Id，返回腾讯云每个地域的可用区代码\n        :type ZoneId: int\n        :param ExpireTime: 过期时间\n        :type ExpireTime: int\n        :param SgList: 安全组详情信息
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgList: list of UsgRuleDetail\n        :param SubnetName: 子网名
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SubnetName: str\n        :param RegionName: 地域名
-注意：此字段可能返回 null，表示取不到有效值。\n        :type RegionName: str\n        :param ZoneName: 区域名
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ZoneName: str\n        :param Expired: 实例是否已经过期
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Expired: bool\n        :param RemainSeconds: 为正数表示实例距离过期时间剩余秒数，为负数表示实例已经过期多少秒
-注意：此字段可能返回 null，表示取不到有效值。\n        :type RemainSeconds: int\n        :param VpcName: 私有虚拟网络名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcName: str\n        :param VpcCidrBlock: VPC的IPv4 CIDR
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcCidrBlock: str\n        :param SubnetCidrBlock: 子网的CIDR
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SubnetCidrBlock: str\n        :param Tags: 资源所关联的Tag
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Tags: list of Tag\n        :param RenewFlag: 资源续费标识，0表示默认状态(用户未设置，即初始状态)， 1表示自动续费，2表示明确不自动续费(用户设置)
-注意：此字段可能返回 null，表示取不到有效值。\n        :type RenewFlag: int\n        :param Manufacturer: 厂商
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Manufacturer: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.ResourceId = None
         self.ResourceName = None
         self.Status = None
@@ -442,13 +577,26 @@ class DescribeVsmsRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Offset: 偏移
+        :type Offset: int
+        :param Limit: 最大数量
+        :type Limit: int
+        :param SearchWord: 查询关键字
+        :type SearchWord: str
+        :param TagFilters: 标签过滤条件
+        :type TagFilters: list of TagFilter
+        :param Manufacturer: 设备所属的厂商名称，根据厂商来进行筛选
+        :type Manufacturer: str
+        :param HsmType: Hsm服务类型，可选virtualization、physical、GHSM、EHSM、SHSM、all
+        :type HsmType: str
         """
-        :param Offset: 偏移\n        :type Offset: int\n        :param Limit: 最大数量\n        :type Limit: int\n        :param SearchWord: 查询关键字\n        :type SearchWord: str\n        :param TagFilters: 标签过滤条件\n        :type TagFilters: list of TagFilter\n        :param Manufacturer: 设备所属的厂商名称，根据厂商来进行筛选\n        :type Manufacturer: str\n        """
         self.Offset = None
         self.Limit = None
         self.SearchWord = None
         self.TagFilters = None
         self.Manufacturer = None
+        self.HsmType = None
 
 
     def _deserialize(self, params):
@@ -462,6 +610,7 @@ class DescribeVsmsRequest(AbstractModel):
                 obj._deserialize(item)
                 self.TagFilters.append(obj)
         self.Manufacturer = params.get("Manufacturer")
+        self.HsmType = params.get("HsmType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -477,9 +626,15 @@ class DescribeVsmsResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCount: 获取实例的总个数
+        :type TotalCount: int
+        :param VsmList: 资源信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VsmList: list of ResourceInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCount: 获取实例的总个数\n        :type TotalCount: int\n        :param VsmList: 资源信息
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VsmList: list of ResourceInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.VsmList = None
         self.RequestId = None
@@ -502,8 +657,12 @@ class DeviceInfo(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Manufacturer: 厂商名称
+        :type Manufacturer: str
+        :param HsmTypes: 此厂商旗下的设备信息列表
+        :type HsmTypes: list of HsmInfo
         """
-        :param Manufacturer: 厂商名称\n        :type Manufacturer: str\n        :param HsmTypes: 此厂商旗下的设备信息列表\n        :type HsmTypes: list of HsmInfo\n        """
         self.Manufacturer = None
         self.HsmTypes = None
 
@@ -531,8 +690,12 @@ class HsmInfo(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Model: 加密机型号
+        :type Model: str
+        :param VsmTypes: 此类型的加密机所支持的VSM类型列表
+        :type VsmTypes: list of VsmInfo
         """
-        :param Model: 加密机型号\n        :type Model: str\n        :param VsmTypes: 此类型的加密机所支持的VSM类型列表\n        :type VsmTypes: list of VsmInfo\n        """
         self.Model = None
         self.VsmTypes = None
 
@@ -560,14 +723,29 @@ class InquiryPriceBuyVsmRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param GoodsNum: 需购买实例的数量
+        :type GoodsNum: int
+        :param PayMode: 付费模式：0表示按需计费/后付费，1表示预付费
+        :type PayMode: int
+        :param TimeSpan: 商品的时间大小，整型参数，举例：当TimeSpan为1，TImeUnit为m时，表示询价购买时长为1个月时的价格
+        :type TimeSpan: str
+        :param TimeUnit: 商品的时间单位，m表示月，y表示年
+        :type TimeUnit: str
+        :param Currency: 货币类型，默认为CNY
+        :type Currency: str
+        :param Type: 默认为CREATE，可选RENEW
+        :type Type: str
+        :param HsmType: Hsm服务类型，可选值virtualization、physical、GHSM、EHSM、SHSM
+        :type HsmType: str
         """
-        :param GoodsNum: 需购买实例的数量\n        :type GoodsNum: int\n        :param PayMode: 付费模式：0表示按需计费/后付费，1表示预付费\n        :type PayMode: int\n        :param TimeSpan: 商品的时间大小\n        :type TimeSpan: str\n        :param TimeUnit: 商品的时间单位，m表示月，y表示年\n        :type TimeUnit: str\n        :param Currency: 货币类型，默认为CNY\n        :type Currency: str\n        :param Type: 默认为CREATE，可选RENEW\n        :type Type: str\n        """
         self.GoodsNum = None
         self.PayMode = None
         self.TimeSpan = None
         self.TimeUnit = None
         self.Currency = None
         self.Type = None
+        self.HsmType = None
 
 
     def _deserialize(self, params):
@@ -577,6 +755,7 @@ class InquiryPriceBuyVsmRequest(AbstractModel):
         self.TimeUnit = params.get("TimeUnit")
         self.Currency = params.get("Currency")
         self.Type = params.get("Type")
+        self.HsmType = params.get("HsmType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -592,13 +771,25 @@ class InquiryPriceBuyVsmResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCost: 原始总金额，浮点型参数，精确到小数点后两位，如：2000.99
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TotalCost: float
+        :param GoodsNum: 购买的实例数量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type GoodsNum: int
+        :param TimeSpan: 商品的时间大小，整型参数，举例：当TimeSpan为1，TImeUnit为m时，表示询价购买时长为1个月时的价格
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TimeSpan: str
+        :param TimeUnit: 商品的时间单位，m表示月，y表示年
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TimeUnit: str
+        :param OriginalCost: 应付总金额，浮点型参数，精确到小数点后两位，如：2000.99
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OriginalCost: float
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCost: 原始总金额
-注意：此字段可能返回 null，表示取不到有效值。\n        :type TotalCost: float\n        :param GoodsNum: 购买的实例数量
-注意：此字段可能返回 null，表示取不到有效值。\n        :type GoodsNum: int\n        :param TimeSpan: 商品的时间大小
-注意：此字段可能返回 null，表示取不到有效值。\n        :type TimeSpan: str\n        :param TimeUnit: 商品的时间单位
-注意：此字段可能返回 null，表示取不到有效值。\n        :type TimeUnit: str\n        :param OriginalCost: 应付总金额
-注意：此字段可能返回 null，表示取不到有效值。\n        :type OriginalCost: float\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCost = None
         self.GoodsNum = None
         self.TimeSpan = None
@@ -622,11 +813,23 @@ class ModifyVsmAttributesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param ResourceId: 资源Id\n        :type ResourceId: str\n        :param Type: UpdateResourceName-修改资源名称,
+        r"""
+        :param ResourceId: 资源Id
+        :type ResourceId: str
+        :param Type: UpdateResourceName-修改资源名称,
 UpdateSgIds-修改安全组名称,
 UpdateNetWork-修改网络,
-Default-默认不修改\n        :type Type: list of str\n        :param ResourceName: 资源名称\n        :type ResourceName: str\n        :param SgIds: 安全组Id\n        :type SgIds: list of str\n        :param VpcId: 虚拟专网Id\n        :type VpcId: str\n        :param SubnetId: 子网Id\n        :type SubnetId: str\n        """
+Default-默认不修改
+        :type Type: list of str
+        :param ResourceName: 资源名称
+        :type ResourceName: str
+        :param SgIds: 安全组Id
+        :type SgIds: list of str
+        :param VpcId: 虚拟专网Id
+        :type VpcId: str
+        :param SubnetId: 子网Id
+        :type SubnetId: str
+        """
         self.ResourceId = None
         self.Type = None
         self.ResourceName = None
@@ -657,8 +860,10 @@ class ModifyVsmAttributesResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -672,30 +877,74 @@ class ResourceInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源Id
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ResourceId: str\n        :param ResourceName: 资源名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ResourceName: str\n        :param Status: 资源状态
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Status: int\n        :param Vip: 资源IP
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Vip: str\n        :param VpcId: 资源所属Vpc
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcId: str\n        :param SubnetId: 资源所属子网
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SubnetId: str\n        :param Model: 资源所属HSM规格
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Model: str\n        :param VsmType: 资源类型
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VsmType: int\n        :param RegionId: 地域Id
-注意：此字段可能返回 null，表示取不到有效值。\n        :type RegionId: int\n        :param ZoneId: 区域Id
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ZoneId: int\n        :param ExpireTime: 过期时间
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ExpireTime: int\n        :param RegionName: 地域名
-注意：此字段可能返回 null，表示取不到有效值。\n        :type RegionName: str\n        :param ZoneName: 区域名
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ZoneName: str\n        :param SgList: 实例的安全组列表
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgList: list of SgUnit\n        :param SubnetName: 子网名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SubnetName: str\n        :param Expired: 当前实例是否已经过期
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Expired: bool\n        :param RemainSeconds: 为正数表示实例距离过期时间还剩余多少秒，为负数表示已经过期多少秒
-注意：此字段可能返回 null，表示取不到有效值。\n        :type RemainSeconds: int\n        :param VpcName: Vpc名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcName: str\n        :param CreateUin: 创建者Uin账号
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CreateUin: str\n        :param RenewFlag: 自动续费状态标识， 0-手动续费，1-自动续费，2-到期不续
-注意：此字段可能返回 null，表示取不到有效值。\n        :type RenewFlag: int\n        :param Tags: 标签列表
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Tags: list of Tag\n        :param Manufacturer: 厂商
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Manufacturer: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ResourceId: str
+        :param ResourceName: 资源名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ResourceName: str
+        :param Status: 资源状态，1-正常，2-隔离，3-销毁
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Status: int
+        :param Vip: 资源IP
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Vip: str
+        :param VpcId: 资源所属Vpc
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcId: str
+        :param SubnetId: 资源所属子网
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubnetId: str
+        :param Model: 资源所属HSM规格
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Model: str
+        :param VsmType: 云加密机类型id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VsmType: int
+        :param RegionId: 地域Id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RegionId: int
+        :param ZoneId: 区域Id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ZoneId: int
+        :param ExpireTime: 过期时间（Epoch Unix Timestamp）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExpireTime: int
+        :param RegionName: 地域名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RegionName: str
+        :param ZoneName: 区域名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ZoneName: str
+        :param SgList: 实例的安全组列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgList: list of SgUnit
+        :param SubnetName: 子网名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubnetName: str
+        :param Expired: 当前实例是否已经过期
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Expired: bool
+        :param RemainSeconds: 为正数表示实例距离过期时间还剩余多少秒，为负数表示已经过期多少秒
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RemainSeconds: int
+        :param VpcName: Vpc名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcName: str
+        :param CreateUin: 创建者Uin账号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreateUin: str
+        :param RenewFlag: 自动续费状态标识， 0-手动续费，1-自动续费，2-到期不续
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RenewFlag: int
+        :param Tags: 标签列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Tags: list of Tag
+        :param Manufacturer: 厂商
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Manufacturer: str
+        """
         self.ResourceId = None
         self.ResourceName = None
         self.Status = None
@@ -768,12 +1017,20 @@ class SgUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SgId: 安全组Id
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgId: str\n        :param SgName: 安全组名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgName: str\n        :param SgRemark: 备注
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgRemark: str\n        :param CreateTime: 创建时间
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CreateTime: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgId: str
+        :param SgName: 安全组名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgName: str
+        :param SgRemark: 备注
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgRemark: str
+        :param CreateTime: 创建时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreateTime: str
+        """
         self.SgId = None
         self.SgName = None
         self.SgRemark = None
@@ -800,17 +1057,35 @@ class Subnet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param VpcId: VPC实例ID。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcId: str\n        :param SubnetId: 子网实例ID，例如：subnet-bthucmmy。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SubnetId: str\n        :param SubnetName: 子网名称。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SubnetName: str\n        :param CidrBlock: 子网的 IPv4 CIDR。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CidrBlock: str\n        :param CreatedTime: 创建时间。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CreatedTime: str\n        :param AvailableIpAddressCount: 可用IP数。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type AvailableIpAddressCount: int\n        :param Ipv6CidrBlock: 子网的 IPv6 CIDR。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Ipv6CidrBlock: str\n        :param TotalIpAddressCount: 总IP数
-注意：此字段可能返回 null，表示取不到有效值。\n        :type TotalIpAddressCount: int\n        :param IsDefault: 是否为默认Subnet
-注意：此字段可能返回 null，表示取不到有效值。\n        :type IsDefault: bool\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcId: str
+        :param SubnetId: 子网实例ID，例如：subnet-bthucmmy。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubnetId: str
+        :param SubnetName: 子网名称。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubnetName: str
+        :param CidrBlock: 子网的 IPv4 CIDR。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CidrBlock: str
+        :param CreatedTime: 创建时间。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreatedTime: str
+        :param AvailableIpAddressCount: 可用IP数。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AvailableIpAddressCount: int
+        :param Ipv6CidrBlock: 子网的 IPv6 CIDR。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Ipv6CidrBlock: str
+        :param TotalIpAddressCount: 总IP数
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TotalIpAddressCount: int
+        :param IsDefault: 是否为默认Subnet
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsDefault: bool
+        """
         self.VpcId = None
         self.SubnetId = None
         self.SubnetName = None
@@ -847,8 +1122,12 @@ class Tag(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TagKey: 标签键
+        :type TagKey: str
+        :param TagValue: 标签值
+        :type TagValue: str
         """
-        :param TagKey: 标签键\n        :type TagKey: str\n        :param TagValue: 标签值\n        :type TagValue: str\n        """
         self.TagKey = None
         self.TagValue = None
 
@@ -871,8 +1150,12 @@ class TagFilter(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TagKey: 标签键
+        :type TagKey: str
+        :param TagValue: 标签值
+        :type TagValue: list of str
         """
-        :param TagKey: 标签键\n        :type TagKey: str\n        :param TagValue: 标签值\n        :type TagValue: list of str\n        """
         self.TagKey = None
         self.TagValue = None
 
@@ -895,16 +1178,32 @@ class UsgPolicy(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Ip: cidr格式地址
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Ip: str\n        :param Id: 安全组id代表的地址集合
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Id: str\n        :param AddressModule: 地址组id代表的地址集合
-注意：此字段可能返回 null，表示取不到有效值。\n        :type AddressModule: str\n        :param Proto: 协议
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Proto: str\n        :param Port: 端口
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Port: str\n        :param ServiceModule: 服务组id代表的协议和端口集合
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ServiceModule: str\n        :param Desc: 备注
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Desc: str\n        :param Action: 匹配后行为:ACCEPT/DROP
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Action: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Ip: str
+        :param Id: 安全组id代表的地址集合
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Id: str
+        :param AddressModule: 地址组id代表的地址集合
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AddressModule: str
+        :param Proto: 协议
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Proto: str
+        :param Port: 端口
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Port: str
+        :param ServiceModule: 服务组id代表的协议和端口集合
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ServiceModule: str
+        :param Desc: 备注
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Desc: str
+        :param Action: 匹配后行为:ACCEPT/DROP
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Action: str
+        """
         self.Ip = None
         self.Id = None
         self.AddressModule = None
@@ -939,15 +1238,29 @@ class UsgRuleDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InBound: 入站规则
-注意：此字段可能返回 null，表示取不到有效值。\n        :type InBound: list of UsgPolicy\n        :param OutBound: 出站规则
-注意：此字段可能返回 null，表示取不到有效值。\n        :type OutBound: list of UsgPolicy\n        :param SgId: 安全组Id
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgId: str\n        :param SgName: 安全组名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgName: str\n        :param SgRemark: 备注
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SgRemark: str\n        :param CreateTime: 创建时间
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CreateTime: str\n        :param Version: 版本
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Version: int\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type InBound: list of UsgPolicy
+        :param OutBound: 出站规则
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OutBound: list of UsgPolicy
+        :param SgId: 安全组Id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgId: str
+        :param SgName: 安全组名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgName: str
+        :param SgRemark: 备注
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SgRemark: str
+        :param CreateTime: 创建时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreateTime: str
+        :param Version: 版本
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Version: int
+        """
         self.InBound = None
         self.OutBound = None
         self.SgId = None
@@ -990,12 +1303,20 @@ class Vpc(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param VpcName: Vpc名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcName: str\n        :param VpcId: VpcId
-注意：此字段可能返回 null，表示取不到有效值。\n        :type VpcId: str\n        :param CreatedTime: 创建时间
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CreatedTime: str\n        :param IsDefault: 是否为默认VPC
-注意：此字段可能返回 null，表示取不到有效值。\n        :type IsDefault: bool\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcName: str
+        :param VpcId: VpcId
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VpcId: str
+        :param CreatedTime: 创建时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreatedTime: str
+        :param IsDefault: 是否为默认VPC
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsDefault: bool
+        """
         self.VpcName = None
         self.VpcId = None
         self.CreatedTime = None
@@ -1022,8 +1343,12 @@ class VsmInfo(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TypeName: VSM类型名称
+        :type TypeName: str
+        :param TypeID: VSM类型值
+        :type TypeID: int
         """
-        :param TypeName: VSM类型名称\n        :type TypeName: str\n        :param TypeID: VSM类型值\n        :type TypeID: int\n        """
         self.TypeName = None
         self.TypeID = None
 
